@@ -26,7 +26,7 @@
 # --- System guessing --- #
 
 
-$SCRIPTSDIR = "";
+$SCRIPTSDIR = "/opt/kde/share/apps/knetworkconf/backends";
 if ($SCRIPTSDIR =~ /^@scriptsdir[@]/)
 {
     $SCRIPTSDIR = ".";
@@ -79,6 +79,7 @@ $PLATFORM_INFO = {
   "mandriva-2008.1"   => "Mandriva Linux 2008.1",
   "mandriva-2009.0"   => "Mandriva Linux 2009.0",
   "mandriva-2009.1"   => "Mandriva Linux 2009.1",
+  "mandriva-2010.0"   => "Mandriva Linux 2010.0",
   "blackpanther-4.0" => "Black Panther OS 4.0",
   "conectiva-9"     => "Conectiva Linux 9",
   "conectiva-10"    => "Conectiva Linux 10",
@@ -103,9 +104,7 @@ $PLATFORM_INFO = {
   "pld-1.99"        => "PLD 1.99 Ac-pre",
   "vine-3.0"        => "Vine Linux 3.0",
   "vine-3.1"        => "Vine Linux 3.1",
-  "fedora-1"        => "Fedora Core 1 (Yarrow)",
-  "fedora-2"        => "Fedora Core 2 (Tettnang)",
-  "fedora-3"        => "Fedora Core 3 (Heidelberg)",
+  "fedora"          => "Fedora",
   "yoper-2.1"       => "Yoper Linux  2.1 (for i686)",
   "yoper-2.2"       => "Yoper Linux  2.2 (for i686)",  
   "specifix"        => "Specifix Linux",
@@ -295,20 +294,7 @@ sub check_blackpanther
 
 sub check_fedora
 {
-    open FEDORA, "$gst_prefix/etc/fedora-release" or return -1;
-    while (<FEDORA>)
-    {
-      $ver = $_;
-      chomp ($ver);
-
-      if ($ver =~ /^Fedora Core release (\S+)/)
-      {
-        close FEDORA;
-        return "fedora-$1";
-      }
-    }
-
-    close FEDORA;
+    return "fedora" if stat ("$gst_prefix/etc/fedora-release");
     return -1;
 }
 
